# Contributing to iCal-library

As an open source project, iCal-library welcomes contributions of many forms.
This document summarizes the process.

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports
* Pull request reviews

Contributions are managed using GitHub's Pull Requests.
For a PR to be accepted:

* All automated checks must pass
* The changeset must have a reasonable patch test coverage
